@@ -888,15 +888,20 @@ def rotation_matrix_from_rpy(rpy):
     return quaternion2matrix(quat_from_rpy(rpy))
 
 
-def rotation_matrix_from_axis(x_axis, y_axis=(0, 1, 0)):
-    """Return rotation matrix orienting x_axis
+def rotation_matrix_from_axis(
+        first_axis=(1, 0, 0), second_axis=(0, 1, 0), axes='xy'):
+    """Return rotation matrix orienting first_axis
 
     Parameters
     ----------
-    x_axis : list or tuple or numpy.ndarray
-        x_axis
-    y_axis : list or tuple or numpy.ndarray
-        y_axis. This input axis is normalized using Gram-Schmidt.
+    first_axis : list or tuple or numpy.ndarray
+        direction of first axis
+    second_axis : list or tuple or numpy.ndarray
+        direction of second axis.
+        This input axis is normalized using Gram-Schmidt.
+    axes : str
+        valid inputs are 'xy', 'yx', 'xz', 'zx', 'yz', 'zy'.
+        first index indicates first_axis's axis.
 
     Returns
     -------
@@ -915,12 +920,21 @@ def rotation_matrix_from_axis(x_axis, y_axis=(0, 1, 0)):
            [ 0.57735027,  0.81649658,  0.        ],
            [ 0.57735027, -0.40824829,  0.70710678]])
     """
-    e1 = normalize_vector(x_axis)
-    e2 = normalize_vector(y_axis - np.dot(y_axis, e1) * e1)
-    z_axis = np.cross(e1, e2)
+    if axes not in ['xy', 'yx', 'xz', 'zx', 'yz', 'zy']:
+        raise ValueError("Valid axes are 'xy', 'yx', 'xz', 'zx', 'yz', 'zy'.")
+    e1 = normalize_vector(first_axis)
+    e2 = normalize_vector(second_axis - np.dot(second_axis, e1) * e1)
+    if axes in ['xy', 'zx', 'yz']:
+        third_axis = np.cross(e1, e2)
+    else:
+        third_axis = np.cross(e2, e1)
     e3 = normalize_vector(
-        z_axis - np.dot(z_axis, e1) * e1 - np.dot(z_axis, e2) * e2)
-    return np.vstack([e1, e2, e3]).T
+        third_axis - np.dot(third_axis, e1) * e1 - np.dot(third_axis, e2) * e2)
+    first_index = ord(axes[0]) - ord('x')
+    second_index = ord(axes[1]) - ord('x')
+    third_index = ((first_index + 1) ^ (second_index + 1)) - 1
+    indices = [first_index, second_index, third_index]
+    return np.vstack([e1, e2, e3])[indices].T
 
 
 def rodrigues(axis, theta=None):
